ErrorChecker

Type Alias ErrorChecker 

pub type ErrorChecker = fn(Option<Box<dyn Error + Send + Sync + 'static>>) -> Result<(), Box<dyn Error + Send + Sync + 'static>>;
An error-checking function: is the value an expected error?

If the checked error is the expected error, the function should return Ok(()). Otherwise, it should just return the checked error, wrapped inside Err.

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 8 bytes